# incentive_lib
Dette er en pakke med utilities bygget for Incentive DK

## Installation

Run the following to install 
```
python -m pip install incentive_lib
```

## Usage

```
import incentive_lib as utils

# e.g. utils.prt(list) prints the list with line separator between items
```


